@@ -46,7 +46,7 @@ atom_num_lab = dict(zip(atom_lab_num.values(), atom_lab_num.keys()))
 
 
 def load_xyz(f_name: str, atomic_numbers: bool = False,
-             add_indices bool = False):
+             add_indices: bool = False):
     """
     Load labels and coordinates from a .xyz file
 
